@@ -1,9 +1,7 @@
-#[macro_use]
-extern crate error_chain;
-
 #[macro_use]
 extern crate clap;
 
+use anyhow::{bail, Context, Result};
 use clap::App;
 use parol::parser::parol_grammar::ParolGrammar;
 use parol::parser::parol_parser::parse;
@@ -23,19 +21,7 @@ use std::fs;
 
 // To rebuild the parser sources from scratch use the command build_parsers.ps1
 
-error_chain! {
-    links {
-        Parol(parol::errors::Error, parol::errors::ErrorKind);
-    }
-    foreign_links {
-        Parse(::std::num::ParseIntError);
-        Log(log::SetLoggerError);
-    }
-}
-
-quick_main!(run);
-
-fn run() -> Result<()> {
+fn main() -> Result<()> {
     // $env:RUST_LOG="parol_runtime=trace,parol=trace"
     // std::env::set_var("RUST_LOG", "parol::analysis::first,parol::analysis::follow,parol::analysis::k_decision,parol::main=trace");
     env_logger::try_init()?;
@@ -58,23 +44,23 @@ fn run() -> Result<()> {
     )?;
 
     write_expanded_grammar(&grammar_config, config.value_of("expanded"))
-        .chain_err(|| "Error writing left-factored grammar!")?;
+        .with_context(|| "Error writing left-factored grammar!")?;
 
     let cfg = check_and_transform_grammar(&grammar_config.cfg)
-        .chain_err(|| "Basic grammar checks and transformations failed!")?;
+        .with_context(|| "Basic grammar checks and transformations failed!")?;
 
     // Exchange original grammar with transformed one
     grammar_config.update_cfg(cfg);
 
     write_expanded_grammar(&grammar_config, config.value_of("expanded"))
-        .chain_err(|| "Error writing left-factored grammar!")?;
+        .with_context(|| "Error writing left-factored grammar!")?;
 
     if !config.is_present("parser") && !config.is_present("only_lookahead") {
         return Ok(());
     }
 
     let lookahead_dfa_s = calculate_lookahead_dfas(&grammar_config, max_k)
-        .chain_err(|| "Lookahead calculation for the given grammar failed!")?;
+        .with_context(|| "Lookahead calculation for the given grammar failed!")?;
 
     if config.is_present("verbose") {
         print!("Lookahead DFAs:\n{:?}", lookahead_dfa_s);
@@ -94,19 +80,19 @@ fn run() -> Result<()> {
         print!("\nGrammar config:\n{:?}", grammar_config);
     }
 
-    let lexer_source =
-        generate_lexer_source(&grammar_config).chain_err(|| "Failed to generate lexer source!")?;
+    let lexer_source = generate_lexer_source(&grammar_config)
+        .with_context(|| "Failed to generate lexer source!")?;
 
     let user_trait_module_name = config.value_of("module").unwrap();
 
     let user_type = config.value_of("user_type").unwrap();
 
     let parser_source = generate_parser_source(&grammar_config, &lexer_source, &lookahead_dfa_s)
-        .chain_err(|| "Failed to generate parser source!")?;
+        .with_context(|| "Failed to generate parser source!")?;
 
     if let Some(parser_file_out) = config.value_of("parser") {
         fs::write(parser_file_out, parser_source)
-            .chain_err(|| "Error writing generated lexer source!")?;
+            .with_context(|| "Error writing generated lexer source!")?;
         try_format(parser_file_out);
     } else if verbose {
         println!("\nParser source:\n{}", parser_source);
@@ -114,10 +100,10 @@ fn run() -> Result<()> {
 
     let user_trait_source =
         generate_user_trait_source(user_type, user_trait_module_name, &grammar_config)
-            .chain_err(|| "Failed to generate user trait source!")?;
+            .with_context(|| "Failed to generate user trait source!")?;
     if let Some(user_trait_file_out) = config.value_of("actions") {
         fs::write(user_trait_file_out, user_trait_source)
-            .chain_err(|| "Error writing generated user trait source!")?;
+            .with_context(|| "Error writing generated user trait source!")?;
         try_format(user_trait_file_out);
     } else if verbose {
         println!("\nSource for semantic actions:\n{}", user_trait_source);
@@ -132,11 +118,11 @@ fn obtain_grammar_config(
     generate_tree_graph: bool,
 ) -> Result<GrammarConfig> {
     if let Some(file_name) = grammar {
-        let input =
-            fs::read_to_string(file_name).chain_err(|| format!("Can't read file {}", file_name))?;
+        let input = fs::read_to_string(file_name)
+            .with_context(|| format!("Can't read file {}", file_name))?;
         let mut parol_grammar = ParolGrammar::new();
         let syntax_tree = parse(&input, file_name.to_owned(), &mut parol_grammar)
-            .chain_err(|| format!("Failed parsing file {}", file_name))?;
+            .with_context(|| format!("Failed parsing file {}", file_name))?;
 
         if verbose {
             println!("{}", parol_grammar);
@@ -144,7 +130,7 @@ fn obtain_grammar_config(
 
         if generate_tree_graph {
             generate_tree_layout(&syntax_tree, file_name)
-                .chain_err(|| "Error generating tree layout")?;
+                .with_context(|| "Error generating tree layout")?;
         }
 
         Ok(GrammarConfig::try_from(parol_grammar)?)
@@ -159,7 +145,8 @@ fn write_expanded_grammar(grammar_config: &GrammarConfig, expanded: Option<&str>
         if *file_name == "--" {
             print!("{}", lf_source);
         } else {
-            fs::write(file_name, lf_source).chain_err(|| "Error writing left-factored grammar!")?;
+            fs::write(file_name, lf_source)
+                .with_context(|| "Error writing left-factored grammar!")?;
         }
     }
     Ok(())
