@@ -1,6 +1,6 @@
-use crate::errors::*;
 use crate::generators::{generate_terminal_name, GrammarConfig};
 use crate::{Pr, StrVec, Symbol, Terminal};
+use anyhow::Result;
 
 #[derive(BartDisplay, Debug, Default)]
 #[template = "templates/user_trait_caller_function_template.rs"]
